@@ -9,10 +9,10 @@ from nix_prefetch_github.command.command_runner import CommandRunnerImpl
 from nix_prefetch_github.controller.nix_prefetch_github_controller import (
     NixPrefetchGithubController,
 )
-from nix_prefetch_github.controller.prefetch_directory_controller import (
+from nix_prefetch_github.controller.nix_prefetch_github_directory_controller import (
     PrefetchDirectoryController,
 )
-from nix_prefetch_github.controller.prefetch_latest_release_controller import (
+from nix_prefetch_github.controller.nix_prefetch_github_latest_release_controller import (
     PrefetchLatestReleaseController,
 )
 from nix_prefetch_github.github import GithubAPIImpl
@@ -24,10 +24,10 @@ from nix_prefetch_github.interfaces import (
 from nix_prefetch_github.list_remote_factory import ListRemoteFactoryImpl
 from nix_prefetch_github.logging import LoggerFactoryImpl
 from nix_prefetch_github.prefetch import PrefetcherImpl
-from nix_prefetch_github.presenter import (
+from nix_prefetch_github.presenter import PresenterImpl
+from nix_prefetch_github.presenter.repository_renderer import (
     JsonRepositoryRenderer,
     NixRepositoryRenderer,
-    PresenterImpl,
 )
 from nix_prefetch_github.process_environment import ProcessEnvironmentImpl
 from nix_prefetch_github.repository_detector import RepositoryDetectorImpl
