@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
 from logging import Logger
-from sys import exit
+from typing import Protocol
 
-from ..interfaces import (
+from nix_prefetch_github.interfaces import (
     Prefetcher,
     PrefetchOptions,
     Presenter,
@@ -11,6 +13,11 @@ from ..interfaces import (
 )
 
 
+class PrefetchDirectoryUseCase(Protocol):
+    def prefetch_directory(self, request: Request) -> None:
+        ...
+
+
 @dataclass
 class Request:
     prefetch_options: PrefetchOptions
@@ -20,7 +27,7 @@ class Request:
 
 
 @dataclass
-class PrefetchDirectoryUseCase:
+class PrefetchDirectoryUseCaseImpl:
     nix_presenter: Presenter
     json_presenter: Presenter
     prefetcher: Prefetcher
@@ -29,9 +36,7 @@ class PrefetchDirectoryUseCase:
 
     def prefetch_directory(self, request: Request) -> None:
         if self.repository_detector.is_repository_dirty(request.directory):
-            self.logger.warning(
-                f"Warning: Git repository at `{request.directory}` is dirty"
-            )
+            self.logger.warning(f"Git repository at `{request.directory}` is dirty")
         repository = self.repository_detector.detect_github_repository(
             request.directory, remote_name=request.remote
         )
@@ -43,6 +48,6 @@ class PrefetchDirectoryUseCase:
             prefetch_options=request.prefetch_options,
         )
         if request.rendering_format == RenderingFormat.json:
-            exit(self.json_presenter.present(prefetch_result))
+            self.json_presenter.present(prefetch_result)
         else:
-            exit(self.nix_presenter.present(prefetch_result))
+            self.nix_presenter.present(prefetch_result)
