@@ -1,7 +1,9 @@
-from dataclasses import dataclass
-from sys import exit
+from __future__ import annotations
 
-from ..interfaces import (
+from dataclasses import dataclass
+from typing import Protocol
+
+from nix_prefetch_github.interfaces import (
     GithubAPI,
     GithubRepository,
     Prefetcher,
@@ -11,6 +13,11 @@ from ..interfaces import (
 )
 
 
+class PrefetchLatestReleaseUseCase(Protocol):
+    def prefetch_latest_release(self, request: Request) -> None:
+        ...
+
+
 @dataclass
 class Request:
     repository: GithubRepository
@@ -19,7 +26,7 @@ class Request:
 
 
 @dataclass
-class PrefetchLatestReleaseUseCase:
+class PrefetchLatestReleaseUseCaseImpl:
     nix_presenter: Presenter
     json_presenter: Presenter
     prefetcher: Prefetcher
@@ -32,7 +39,10 @@ class PrefetchLatestReleaseUseCase:
             rev=revision,
             prefetch_options=request.prefetch_options,
         )
+        self._select_presenter(request).present(prefetch_result)
+
+    def _select_presenter(self, request: Request) -> Presenter:
         if request.rendering_format == RenderingFormat.json:
-            exit(self.json_presenter.present(prefetch_result))
+            return self.json_presenter
         else:
-            exit(self.nix_presenter.present(prefetch_result))
+            return self.nix_presenter
